Rmdawn command-line interface (CLI) — Rmdawn 0.0.1 documentation

# Rmdawn command-line interface (CLI)

## rmdawn

Create an R markdown file from markdown and code files.

param in_files

  The list of the input files.

param out_file

  The name of the output R markdown file.

    rmdawn [OPTIONS] IN_FILES...

Options

`-o````,` `--out_file``<out>`

Arguments

`IN_FILES```

  Required argument(s)

## rmdusk

Extract YAML, markdown, and code files from a R markdown file.

param in_file

  The name of the input R markdown file.

    rmdusk [OPTIONS] IN_FILE

Arguments

`IN_FILE```

  Required argument